@@ -2,20 +2,22 @@
 API <https://archive.org/advancedsearch.php#raw>.
 
 usage: 
-    ia search [--help] <query>... [options...]
+    ia search [--parameters=<key:value>...] [--sort=<field:order>] 
+              [--field=<field>...] <query>...
+    ia search --help
 
 options:
     -h, --help
     -p, --parameters=<key:value>...  Parameters to send with your query.
-    -s, --sort=<field:order>...      Sort search results by specified
-                                     fields. <order> can be either "asc"
-                                     for ascending and "desc" for 
-                                     descending.
+    -s, --sort=<field:order>...      Sort search results by specified fields. 
+                                     <order> can be either "asc" for ascending 
+                                     and "desc" for descending.
     -f, --field=<field>...           Metadata fields to return.
 
 """
+from sys import stdout
+
 from docopt import docopt
-import sys
 
 from internetarchive import search
 
@@ -27,6 +29,7 @@ def main(argv):
     args = docopt(__doc__, argv=argv)
 
     params = dict(p.split(':') for p in args['--parameters'])
+
     if args['--sort']:
         for i, field in enumerate(args['--sort']):
             key = 'sort[{0}]'.format(i)
@@ -38,5 +41,4 @@ def main(argv):
     search_resp = search(query, fields=fields, params=params)
     for result in search_resp.results():
         output = '\t'.join([result.get(f, '') for f in fields]).encode('utf-8')
-        sys.stdout.write(output + '\n')
-    sys.exit(0)
+        stdout.write(output + '\n')
